pkmn-colosseum decompilation progress · ByteMatchpkmn-colosseum is 13.79% decompiled
0.00% fully linked · GameCube
Code (2.50 MB)
Matched13.79% · 344,124 of 2,495,108 bytes (344.12 KB)Fuzzy match28.75% · ≈717,325 of 2,495,108 bytes (717.33 KB), counting partly matched code Fully linked 0.00%
Fully linked
0.00% · 0 of 2,495,108 bytes (0 B)
Matched 13.79%Matched13.79% · 344,124 of 2,495,108 bytes (344.12 KB)
Fuzzy match 28.75%Fuzzy match28.75% · ≈717,325 of 2,495,108 bytes (717.33 KB), counting partly matched code
Data (2.20 MB)
Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB) Fully linked 0.00%Fully linked0.00% · 0 of 2,196,256 bytes (0 B)Matched 0.77%Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB)
7a40ad3 | README: progress update
· No unit breakdown is stored for this commit (it came from decomp.dev's history, which keeps totals only).
Merge pull request #664: verified 97.44 percent source data